@@ -168,10 +168,10 @@ class HelpFormatter(click.HelpFormatter):
         self.buffer += strings
 
     def write_usage(
-        self, prog: str, args: str = "", prefix: Optional[str] = 'Usage:'
+        self, prog: str, args: str = "", prefix: Optional[str] = None
     ) -> None:
-        if prefix:
-            prefix = self.theme.heading(prefix + ' ')
+        prefix = "Usage:" if prefix is None else prefix
+        prefix = self.theme.heading(prefix) + " "
         prog = self.theme.invoked_command(prog)
         super().write_usage(prog, args, prefix)
 
@@ -185,7 +185,9 @@ class HelpFormatter(click.HelpFormatter):
         if help_text and click_version_ge_8_1:
             help_text = inspect.cleandoc(help_text)
         if cmd.deprecated:
-            help_text = "(DEPRECATED) " + help_text
+            # Use the same label as Click:
+            # https://github.com/pallets/click/blob/b0538df/src/click/core.py#L1331
+            help_text = "(Deprecated) " + help_text
         if help_text:
             self.write_paragraph()
             with self.indentation():
@@ -208,7 +210,7 @@ class HelpFormatter(click.HelpFormatter):
             self.write_section(s)
 
     def write_aligned_sections(self, sections: Sequence[HelpSection]) -> None:
-        """Writes multiple aligned definition lists."""
+        """Write multiple aligned definition lists."""
         all_rows = chain.from_iterable(dl.definitions for dl in sections)
         col1_width = self.compute_col1_width(all_rows, self.col1_max_width)
         for s in sections:
@@ -255,7 +257,7 @@ class HelpFormatter(click.HelpFormatter):
         col_spacing: Optional[int] = None,  # default changed to None wrt parent class
         col1_width: Optional[int] = None,
     ) -> None:
-        """Writes a definition list into the buffer. This is how options
+        """Write a definition list into the buffer. This is how options
         and commands are usually formatted.
 
         If there's enough space, definition lists are rendered as a 2-column
@@ -322,7 +324,7 @@ class HelpFormatter(click.HelpFormatter):
         self, rows: Sequence[Definition],
         col1_width: int, col_spacing: int, col2_width: int,
     ) -> None:
-        """Formats a definition list as a 2-column "pseudo-table". If the first
+        """Format a definition list as a 2-column "pseudo-table". If the first
         column of a row exceeds ``col1_width``, the 2nd column is written on
         the subsequent line. This is the standard way of formatting definition
         lists and it's the default if there's enough space."""
@@ -367,7 +369,7 @@ class HelpFormatter(click.HelpFormatter):
             write_row(row)
 
     def write_linear_dl(self, dl: Sequence[Definition]) -> None:
-        """Formats a definition list as a "linear list". This is the default when
+        """Format a definition list as a "linear list". This is the default when
         the available width for the definitions (2nd column) is below
         ``self.col2_min_width``."""
         help_extra_indent = max(3, self.indent_increment)
